
# This file was generated by 'versioneer.py' (0.19) from
# revision-control system data, or from the parent directory name of an
# unpacked source archive. Distribution tarballs contain a pre-generated copy
# of this file.

import json

version_json = '''
{
 "date": "2021-09-07T12:29:17+0200",
 "dirty": false,
 "error": null,
 "full-revisionid": "ca3903ac1d71b40fbf3e2a4b869c9afee8520f6b",
 "version": "0.6.11"
}
'''  # END VERSION_JSON


def get_versions():
    return json.loads(version_json)
